@@ -1,7 +1,13 @@
 package App::Bondage;
+BEGIN {
+  $App::Bondage::AUTHORITY = 'cpan:HINRIK';
+}
+BEGIN {
+  $App::Bondage::VERSION = '0.4.5';
+}
 
 use strict;
-use warnings;
+use warnings FATAL => 'all';
 use Carp;
 use Config;
 use App::Bondage::Away;
@@ -24,7 +30,6 @@ use POE::Component::IRC::Plugin::NickServID;
 use Socket qw(inet_ntoa);
 use YAML::XS qw(LoadFile);
 
-our $VERSION    = '0.4.4';
 our $HOMEPAGE   = 'http://search.cpan.org/perldoc?App::Bondage';
 our $CRYPT_SALT = 'erxpnUyerCerugbaNgfhW';
 
@@ -70,8 +75,15 @@ sub _start {
             plugin_debug => $self->{Debug},
         );
         
+        my $version;
+        {
+            no strict 'vars';
+            $version = defined $App::Bondage::VERSION
+                ? "Bondage $VERSION running on $Config{osname} $Config{osvers} -- $HOMEPAGE"
+                : "Bondage dev-git running on $Config{osname} $Config{osvers}";
+        }
         $irc->plugin_add('CTCP',        POE::Component::IRC::Plugin::CTCP->new(
-            Version => "Bondage $VERSION running on $Config{osname} $Config{osvers} -- $HOMEPAGE"
+            Version => $version,
         ));
         $irc->plugin_add('Cycle',       POE::Component::IRC::Plugin::CycleEmpty->new()) if $network->{cycle_empty};
         $irc->plugin_add('NickReclaim', POE::Component::IRC::Plugin::NickReclaim->new());
@@ -253,7 +265,8 @@ sub _exit {
 }
 
 1;
-__END__
+
+=encoding utf8
 
 =head1 NAME
 
@@ -586,7 +599,7 @@ The following CPAN distributions are required:
 
 =over 
 
-=item L<YAML:XS|YAML::XS>
+=item L<YAML::XS|YAML::XS>
 
 =item L<POE|POE>
 
