@@ -1,7 +1,13 @@
 package App::Bondage::Recall;
+BEGIN {
+  $App::Bondage::Recall::AUTHORITY = 'cpan:HINRIK';
+}
+BEGIN {
+  $App::Bondage::Recall::VERSION = '0.4.5';
+}
 
 use strict;
-use warnings;
+use warnings FATAL => 'all';
 use File::Temp qw(tempfile);
 use POE::Component::IRC::Common qw( parse_user );
 use POE::Component::IRC::Plugin qw( :ALL );
@@ -9,8 +15,6 @@ use POE::Component::IRC::Plugin::BotTraffic;
 use POE::Filter::IRCD;
 use Tie::File;
 
-our $VERSION = '1.5';
-
 sub new {
     my ($package, %self) = @_;
     if (!$self{Mode} || $self{Mode} !~ /missed|all|none/) {
@@ -277,7 +281,8 @@ sub recall {
 }
 
 1;
-__END__
+
+=encoding utf8
 
 =head1 NAME
 
